/*
 * jabak Java Backup
 * 
 * Copyright (C) under the terms of the GNU General Public License
 * as explained in the file "disclaimer.txt"
 */

package backup;

import java.io.File;
import java.util.Vector;

import ui.GuiSettings;

/**
 * file to zip backup utility.  types of backup supported are
 * incremental - differential2differential - differential2full - full.
 * 
 * @author  Georg Dietrich
 * @version 1.3 on 2004-04-13
 * @version 1.2 on 2004-04-10
 * @version 1.0 on 2004-04-08
 */
public class CoreMain {

	public CoreMain(GuiSettings guiSettings) {

		// translate GuiSettings to CoreSettings
		Settings settings = new Settings();
		
		// source root path
		settings.sourceRootPath = Util.canonicalPath(new File(guiSettings.source));
		
		// backup path and backup root path - include time stamp
		String backupPath = Util.canonicalPath(new File(guiSettings.backupRoot))
		 										+ File.separator + settings.backupTime;
		settings.backupRootPath = backupPath + File.separator + "backup";
		                         
		// data root path - include source localization stamp
		settings.dataRootPath  = Util.canonicalPath(new File(guiSettings.dataRoot)) + File.separator;
		settings.dataRootPath += settings.sourceRootPath.replaceAll("\\W","_").replaceAll("__","_");
		
		// other settings
		settings.backupSize = ((long)Util.parseInt(guiSettings.size))*1000000;
		settings.backupType = guiSettings.backupType;
		
		// scan status of last backup.
		BackupFile.scan(settings);
		
		// if this backup has higher priority than an interrupted backup, ignore all BackupFile settings
		if (settings.backupContinued < settings.backupType) {
			settings.backupContinued = 0;
			settings.earlierBackups  = new Vector();
		}
		
		// if this backup has lower priority than an interrupted backup, stop backup
		if (settings.backupContinued > settings.backupType) {
			guiSettings.result = "first finish the backup of type "+settings.backupContinued+"\n"+
			                     "before starting a backup of type "+settings.backupType+"!";
			return;
		}

		// create backup files
		Util.recurseDirectoryFilter(new File(settings.sourceRootPath), new Backup(settings), settings);

		// if no data were saved, quit
		if (settings.currentSize == 0) {
			guiSettings.result = "Nothing to do: it seems to me all files are already\n"+
			                     "taken care of in earlier backups";
			return;
		}

		// update backup dependency chain
		new Dependencies (new File(settings.dataRootPath+".dependencies"),settings);

		// save a description of this backup in the backup directory
		new BackupDescription (new File(backupPath+File.separator+"readme.txt"),settings);
		
		// clean up
		if (settings.backupFinished) {
			
			// backup finished - remove backup file
			BackupFile.remove(settings);
			
			// check backup data entries for orphan files
			Util.recurseDirectory(new File(settings.dataRootPath), new DataCheck(settings));

			// generate filelist.zip file
			new FileList(new File(backupPath+File.separator+"filelist.zip"),settings);

			// exit with result message
			guiSettings.result = "Backup complete.\n";
			return;

		} else {
			
			// backup still incomplete - update backup file
			BackupFile.update(settings);

			// exit with result message
			guiSettings.result = "Backup reached size limit.  Start backup again\n"+
					 							   "with the same parameters to cover the rest.";
			return;
		}
	}
}
