/*
 * jabak Java Backup
 * 
 * Copyright (C) under the terms of the GNU General Public License
 * as explained in the file "disclaimer.txt"
 */

package backup;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.util.Enumeration;
import java.util.Vector;

/**
 * @author  Georg Dietrich
 * @version 1.0 on 2004-04-11
 */
public class Dependencies {

	public Dependencies (File file, Settings settings) {
		// file data fields
		String full = "";
		Vector diff = new Vector();
		Vector incr = new Vector();
		
		// parse old file
		if (file.exists()) {
			try {
				BufferedReader reader = new BufferedReader(new FileReader(file));
				
				if (!reader.readLine().equals("gb_1.0")) { 
					System.err.println("conflicting versions in data file "+file);
					System.err.println("remove file and try again.");
					throw new RuntimeException();
				}

				reader.readLine(); // "."
				reader.readLine(); // "full backup"
				full = reader.readLine();
				reader.readLine(); // "."
				reader.readLine(); // "differential backups"
				for (String string = reader.readLine(); !string.equals("."); string = reader.readLine()) {
					diff.add(string);
				}
				reader.readLine(); // "incremental backups"
				for (String string = reader.readLine(); !string.equals("."); string = reader.readLine()) {
					incr.add(string);
				}

				reader.close();
			} catch (Exception e) {
				System.err.println("read dependencies failed for "+file);
				e.printStackTrace();
				throw new RuntimeException();
			}
		}
		
		// update data
		switch (settings.backupType) {
			case 4:
			full = settings.backupTime;
			diff = new Vector();
			incr = new Vector();
			break;
			
			case 3:
			diff = new Vector();
			diff.add (settings.backupTime);
			incr = new Vector();
			break;
			
			case 2:
			diff.add (settings.backupTime);
			incr = new Vector();
			break;

			case 1:
			incr.add (settings.backupTime);
			break;
			
			default:
			System.err.println("update dependencies failed");
			throw new RuntimeException();
		}
		
		// write data into list
		settings.dependencies = new Vector();
		settings.dependencies.add ("full backup:");
		settings.dependencies.add (full);
		settings.dependencies.add ("");
		settings.dependencies.add ("differential backup(s):");
		settings.dependencies.addAll(diff);
		settings.dependencies.add ("");
		settings.dependencies.add ("incremental backup(s):");
		settings.dependencies.addAll(incr);
		
		// write new file
		try {

			BufferedWriter writer = new BufferedWriter(new FileWriter(file));

			writer.write("gb_1.0"); writer.newLine();
			writer.write("."); writer.newLine();
			writer.write("full backup"); writer.newLine();
			writer.write(full); writer.newLine();
			writer.write("."); writer.newLine();
			writer.write("differential backups"); writer.newLine();
			for (Enumeration e = diff.elements(); e.hasMoreElements(); ) {
				writer.write(e.nextElement().toString()); writer.newLine();
			}
			writer.write("."); writer.newLine();
			writer.write("incremental backups"); writer.newLine();
			for (Enumeration e = incr.elements(); e.hasMoreElements(); ) {
				writer.write(e.nextElement().toString()); writer.newLine();
			}
			writer.write("."); writer.newLine();

			writer.close();

		} catch (Exception e) {
			System.err.println("write dependencies failes for "+file);
			e.printStackTrace();
			throw new RuntimeException();
		}
	}

}
