/*
 * jabak Java Backup
 * 
 * Copyright (C) under the terms of the GNU General Public License
 * as explained in the file "disclaimer.txt"
 */

package ui;

import javax.swing.JProgressBar;
import javax.swing.SwingUtilities;

/**
 * Extension of the ProgressInterface of the backup core
 * to display progress within the ui.
 * 
 * @author  Georg Dietrich
 * @version 1.2 on 2004-04-18
 * @version 1.1 on 2004-04-14
 * @version 1.0 on 2004-04-11
 */
public class ProgressInterface extends backup.ProgressInterface {

	protected JProgressBar jProgressBar;

	/**
	 * constructor: save the progress bar object for further reference
	 * 
	 * @param bar  the progress bar to use
	 */
	public ProgressInterface (JProgressBar bar) {
		jProgressBar = bar;
	}

	/**
	 * update the progress bar with new numbers
	 */
	protected void update(final long size, final long sizeMax, final int numFiles, final int skipFiles) {

		// construct a runnable out of the update code
		Runnable updateCode = new Runnable() {
			public void run() {
				// update the percentile value of the progress bar
				// float used to avoid overflows
				jProgressBar.setValue((int)((float)size*100/sizeMax));
				// update the string displayed in the progress bar
				jProgressBar.setString(skipFiles + " skipped / "+numFiles+" backed up");
			}
		};
		
		// execute the runnable within the GUI thread
		SwingUtilities.invokeLater(updateCode);
	}

}
